Pipeline
========

Pipeline is an asset packaging library for Django, providing both CSS and
JavaScript concatenation and compression, built-in JavaScript template support,
and optional data-URI image and font embedding.

Installation
------------

To install it, simply: ::

    pip install django-pipeline


Documentation
-------------

For documentation, usage, and examples, see :
http://django-pipeline.readthedocs.org

Contribute
----------

#. Check for open issues or open a fresh issue to start a discussion around a
   feature idea or a bug. There is a **contribute!** tag for issues that should be
   ideal for people who are not very familiar with the codebase yet.
#. Fork the repository on Github to start making your changes on a topic branch.
#. Write a test which shows that the bug was fixed or that the feature works as expected.
#. Send a pull request and bug the maintainer until it gets merged and published.
   Make sure to add yourself to *AUTHORS*.

Otherwise, if you simply wants to suggest a feature or report a bug, create an issue :
https://github.com/cyberdelia/django-pipeline/issues
